@@ -8,7 +8,7 @@ use Sietima::Types qw(EmailMIME TagName);
 use Digest::SHA qw(sha1_hex);
 use namespace::clean;
 
-our $VERSION = '1.1.0'; # VERSION
+our $VERSION = '1.1.1'; # VERSION
 # ABSTRACT: filesystem-backed email store
 
 
@@ -150,7 +150,7 @@ Sietima::MailStore::FS - filesystem-backed email store
 
 =head1 VERSION
 
-version 1.1.0
+version 1.1.1
 
 =head1 SYNOPSIS
 
@@ -185,7 +185,7 @@ group-writable and group-sticky, and owned by that group:
   my $id = $store->store($email_mime_object,@tags);
 
 Stores the given email message inside the L<store root|/root>, and
-associates with the given tags.
+associates it with the given tags.
 
 Returns a unique identifier for the stored message. If you store twice
 the same message (or two messages that stringify identically), you'll
@@ -221,7 +221,7 @@ returns an empty arrayref.
 This method is similar to L<< /C<retrieve_ids_by_tags> >>, but it
 returns an arrayref of hashrefs like:
 
- $store->retrieve_ids_by_tags('t1') ==> [
+ $store->retrieve_by_tags('t1') ==> [
    { id => $id1, mail => $msg1 },
    { id => $id2, mail => $msg2 },
   ]
