@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use feature ':5.36';
 
-our $VERSION = '1.1.0'; # VERSION
+our $VERSION = '1.1.1'; # VERSION
 # ABSTRACT: pragma for Sietima modules
 
 
@@ -31,15 +31,14 @@ Sietima::Policy - pragma for Sietima modules
 
 =head1 VERSION
 
-version 1.1.0
+version 1.1.1
 
 =head1 SYNOPSIS
 
-  use 5.024;
+  use v5.36;
   use strict;
   use warnings;
-  use feature ':5.24';
-  use experimental 'signatures';
+  use feature ':5.36';
 
 or just:
 
